/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JFileChooser;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.impl.WorkspaceImpl;
import com.eviware.soapui.support.ExtensionFileFilter;

/**
 * Actions for importing an existing soapui-project file into the current workspace
 * 
 * @author Ole.Matzura
 */

public class ImportWsdlProjectAction extends AbstractAction
{
   private JFileChooser chooser;
	private final WorkspaceImpl workspace;

   public ImportWsdlProjectAction( WorkspaceImpl workspace )
   {
      super( "Import Project" );
		this.workspace = workspace;
      putValue( Action.SHORT_DESCRIPTION, "Adds an existing project into this workspace" );
   }

   public JFileChooser getChooser()
   {
      if( chooser == null )
      {
         chooser = new JFileChooser();
         chooser.setDialogTitle("Select soapui project file");
         chooser.setAcceptAllFileFilterUsed( true );
         chooser.setFileFilter( new ExtensionFileFilter( ".xml", "XML Files (*.xml)"));
      }
      
      return chooser;
   }
   
   public void actionPerformed(ActionEvent e)
	{
      JFileChooser chooser = getChooser();
      if( chooser.showOpenDialog( SoapUI.getInstance().getFrame() ) != JFileChooser.APPROVE_OPTION ) return;
      String fileName = chooser.getSelectedFile().getAbsolutePath();
      if( fileName == null ) return;
      
      workspace.importProject( fileName );
   }
}