/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.wsdl.actions.iface;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.BorderFactory;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.KeyStroke;
import javax.swing.ListSelectionModel;
import javax.swing.ScrollPaneConstants;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.impl.wsdl.WsdlInterface;
import com.jgoodies.forms.builder.ButtonBarBuilder;

/**
 * Edits the service endpoints for a WsdlInterface
 * 
 * @author Ole.Matzura
 */

public class InterfaceEndpointsAction extends AbstractAction
{
   private JDialog dialog;
   private JList list;
   private WsdlInterface iface;
   private DefaultListModel listModel;

   public InterfaceEndpointsAction( WsdlInterface iface )
   {
      super( "Service Endpoints" );
      putValue( Action.SHORT_DESCRIPTION, "Manage service endpoints available for this interface" );
      this.iface = iface;
   }

   public KeyStroke getAccelerator()
	{
		return KeyStroke.getKeyStroke( KeyEvent.VK_E, KeyEvent.CTRL_MASK );
	}

	private void buildDialog()
	{
		dialog = new JDialog( SoapUI.getInstance().getFrame() );
      dialog.setTitle("Interface Service Endpoints" );
      
      JPanel contentPanel = new JPanel( new BorderLayout() );
      listModel = new DefaultListModel();
      list = new JList( listModel );
      list.setBorder(BorderFactory.createEmptyBorder(2, 2, 2, 2));
      list.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );
      JScrollPane scrollPane = new JScrollPane( list );
      
      scrollPane.setBorder( BorderFactory.createCompoundBorder(
      		BorderFactory.createEmptyBorder( 0, 3, 0, 3 ), BorderFactory.createLineBorder( Color.GRAY )));
      
      scrollPane.setVerticalScrollBarPolicy( ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS );
      
      contentPanel.add( scrollPane, BorderLayout.CENTER );
      contentPanel.add( createButtons(), BorderLayout.SOUTH );
      JLabel label = new JLabel( "Edit available service endpoints for this interface in list below" );
      label.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
      contentPanel.add( label, BorderLayout.NORTH );
      
      dialog.setContentPane( contentPanel );
      dialog.setSize(400, 300);
      
      dialog.setModal( true );
	}
	
   public void actionPerformed(ActionEvent e)
	{
   	if( dialog == null )
   		buildDialog();
   	
      listModel.clear();
      
      String[] endpoints = iface.getEndpoints();
      for( int c = 0; c < endpoints.length; c++ )
      {
         listModel.addElement( endpoints[c] );
      }
      
      SoapUI.centerDialog( dialog );
      dialog.setVisible( true );
   }

   private Component createButtons()
   {
      ButtonBarBuilder builder = ButtonBarBuilder.createLeftToRightBuilder();
      builder.addFixed( new JButton( new AddAction() ));
      builder.addRelatedGap();
      builder.addFixed( new JButton( new EditAction() ));
      builder.addRelatedGap();
      builder.addFixed( new JButton( new DeleteAction() ));
      builder.addGlue();
      builder.addFixed( new JButton( new OkAction() ));
      builder.addRelatedGap();
      builder.addFixed( new JButton( new CancelAction() ));
      builder.getPanel().setBorder( BorderFactory.createEmptyBorder(5, 5, 5, 5));
      return builder.getPanel();
   }
   
   private class AddAction extends AbstractAction
   {
      public AddAction()
      {
         super( "Add" );
      }
      
      public void actionPerformed(ActionEvent e)
      {
         String endpoint = JOptionPane.showInputDialog( dialog, "Enter new endpoint address", list.getSelectedValue() );
         if( endpoint == null ) return;
         
         listModel.addElement( endpoint );
      }
   }
   
   private class EditAction extends AbstractAction
   {
      public EditAction()
      {
         super( "Edit" );
      }
      
      public void actionPerformed(ActionEvent e)
      {
         int selectedIndex = list.getSelectedIndex();
         if( selectedIndex == -1 ) return;
         String endpoint = (String) listModel.getElementAt( selectedIndex );
         endpoint = JOptionPane.showInputDialog( dialog, "Edit endpoint address", endpoint );
         if( endpoint == null ) return;
         
         listModel.setElementAt( endpoint, selectedIndex );
      }
   }
   
   private class DeleteAction extends AbstractAction
   {
      public DeleteAction()
      {
         super( "Delete" );
      }
      
      public void actionPerformed(ActionEvent e )
      {   
         int index = list.getSelectedIndex();
         if( index != -1)
         	listModel.removeElementAt( index );
      }
   }

   private class OkAction extends AbstractAction
   {
      public OkAction()
      {
         super( "OK" );
      }
      
      public void actionPerformed(ActionEvent e)
      {
         iface.clearEndpoints();
         for( int c = 0; c < listModel.getSize(); c++ )
         {
            iface.addEndpoint( (String) listModel.getElementAt( c ));
         }
         
         dialog.setVisible( false );  
      }
   }
   
   private class CancelAction extends AbstractAction
   {
      public CancelAction()
      {
         super( "Cancel" );
      }
      
      public void actionPerformed(ActionEvent e)
      {
         dialog.setVisible( false );
      }
   }
   
}
