/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.wsdl.actions.project;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JFileChooser;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.impl.wsdl.WsdlProject;
import com.eviware.soapui.model.iface.Interface;
import com.eviware.soapui.support.ExtensionFileFilter;

/**
 * Adds a WsdlInterface to a WsdlProject from a wsdl file
 * 
 * @author Ole.Matzura
 */

public class AddInterfaceActionFromFile extends AbstractAction
{
   private JFileChooser chooser;
	private final WsdlProject project;

   public AddInterfaceActionFromFile( WsdlProject project ) 
   {
      super( "Add WSDL from file" );
		this.project = project;
      putValue( Action.SHORT_DESCRIPTION, "Adds all interfaces in a specified local WSDL file to the current project" );
   }
   
   public JFileChooser getChooser()
   {
      if( chooser == null )
      {
         chooser = new JFileChooser();
         chooser.setDialogTitle("Select WSDL file");
         chooser.setAcceptAllFileFilterUsed( true );
         chooser.setFileFilter( new ExtensionFileFilter( ".wsdl", "WSDL Files (*.wsdl)"));
      }
      
      return chooser;
   }
   
   public void actionPerformed(ActionEvent e)
	{
      JFileChooser chooser = getChooser();
      if( chooser.showOpenDialog( SoapUI.getInstance().getFrame() ) != JFileChooser.APPROVE_OPTION ) return;
      String url = chooser.getSelectedFile().getAbsolutePath();
      if( url == null ) return;
      
      Interface[] ifaces = project.importWsdl( "file:" + url );
      if( ifaces.length > 0 )
         SoapUI.getInstance().selectModelItem( ifaces[0] );
   }
}
