/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.wsdl.actions.request;

import java.awt.event.ActionEvent;
import java.io.StringWriter;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.xml.namespace.QName;

import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.impl.wsdl.WsdlRequest;
import com.eviware.soapui.support.XmlUtils;

/**
 * Creates an empty WsdlRequest containing a SOAP Envelope and empty Body
 * 
 * @author Ole.Matzura
 */

public class CreateEmptyRequestAction extends AbstractAction
{
   private final WsdlRequest request;

	public CreateEmptyRequestAction( WsdlRequest request )
   {
      super( "Create empty" );
		this.request = request;
      putValue( Action.SMALL_ICON, SoapUI.createImageIcon( "/create_empty_request.gif"));
      putValue( Action.SHORT_DESCRIPTION, "Creates an empty SOAP request" );
   }
   
   public void actionPerformed(ActionEvent e)
   {
      XmlObject object = XmlObject.Factory.newInstance();
      XmlCursor cursor = object.newCursor();
      cursor.toNextToken();
      QName envelopeName = new QName("http://schemas.xmlsoap.org/soap/envelope/", "Envelope");
      cursor.beginElement(envelopeName);
      cursor.toFirstChild();

      cursor.beginElement(new QName("http://schemas.xmlsoap.org/soap/envelope/", "Body"));
      cursor.insertComment( " request body goes here ");

      try
		{
			StringWriter writer = new StringWriter();
			XmlUtils.serializePretty(object, writer);
			request.setRequest(writer.toString());
		}
		catch (Exception e1)
		{
			e1.printStackTrace();
			request.setRequest( object.xmlText() );
		}
   }
}