/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.wsdl.support;

import java.text.Collator;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;

import javax.wsdl.Binding;
import javax.wsdl.BindingOperation;
import javax.wsdl.PortType;
import javax.wsdl.extensions.soap.SOAPBinding;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.eviware.soapui.impl.wsdl.WsdlInterface;
import com.eviware.soapui.impl.wsdl.WsdlOperation;
import com.eviware.soapui.impl.wsdl.WsdlProject;

/**
 * BindingImporter that can import a WsdlInterface from an SOAP/HTTP binding
 * 
 * @author Ole.Matzura
 */

public class SoapHttpBindingImporter implements BindingImporter
{
   private final static Log log = LogFactory.getLog( SoapHttpBindingImporter.class );
   
   public boolean canImport(Binding binding)
   {
      List list = binding.getExtensibilityElements();
      SOAPBinding soapBinding = (SOAPBinding) WsdlUtils.getExtensiblityElement( list, SOAPBinding.class );
      return soapBinding == null ? false : 
         soapBinding.getTransportURI().startsWith( "http://schemas.xmlsoap.org/soap/http" );
   }

   public WsdlInterface importBinding( WsdlProject project, WsdlContext wsdlContext, Binding binding ) throws Exception
   {
      PortType portType = binding.getPortType();
      
      WsdlInterface iface = project.addNewInterface(portType.getQName().getLocalPart());
      iface.setBindingName( binding.getQName() );
      
      String [] endpoints = WsdlUtils.getEndpointsForBinding( wsdlContext.getDefinition(), binding );
      for (int i = 0; i < endpoints.length; i++)
      {
         log.info("importing endpoint " + endpoints[i]);
         iface.addEndpoint( endpoints[i] );
      }
      
      SoapRequestBuilder builder = new SoapRequestBuilder( wsdlContext );
      iface.setSoapRequestBuilder( builder );
      
      List<BindingOperation> list = binding.getBindingOperations();
      Collections.sort( list, new Comparator<BindingOperation>()
      {
         public int compare(BindingOperation o1, BindingOperation o2)
         {
            return Collator.getInstance().compare( o1.getOperation().getName(), o2.getOperation().getName() );
         }
      });
      
      for (Iterator iter = list.iterator(); iter.hasNext();)
      {
         BindingOperation operation = (BindingOperation) iter.next();
         WsdlOperation op = iface.addNewOperation();
         
         log.info("importing operation " + operation.getName() );
         
         op.setAction( WsdlUtils.getSoapAction( operation ));
         op.setName( operation.getOperation().getName() );
         op.setBindingOperationName( operation.getName() );
      }
      
      return iface;
   }
}
