/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.wsdl.teststeps.assertions;

import javax.swing.JOptionPane;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlCursor;
import org.apache.xmlbeans.XmlObject;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.config.RequestAssertionConfig;
import com.eviware.soapui.impl.wsdl.WsdlInterface;
import com.eviware.soapui.impl.wsdl.WsdlOperation;
import com.eviware.soapui.impl.wsdl.support.WsdlContext;
import com.eviware.soapui.impl.wsdl.support.WsdlValidator;
import com.eviware.soapui.impl.wsdl.teststeps.WsdlAssertion;
import com.eviware.soapui.impl.wsdl.teststeps.WsdlTestRequest;
import com.eviware.soapui.impl.wsdl.teststeps.assertions.AssertionError;

/**
 * Asserts that a request or response message complies with its related 
 * WSDL definition / XML Schema
 * 
 * @author Ole.Matzura
 */

public class SchemaComplianceAssertion extends WsdlAssertion
{
	private final static Logger log = Logger.getLogger( SchemaComplianceAssertion.class );
	private String definition;
	
   public SchemaComplianceAssertion(RequestAssertionConfig assertionConfig, WsdlTestRequest request)
   {
      super(assertionConfig, request);
      
      XmlObject[] paths = getConfiguration().selectPath( "$this/definition" );
      if( paths.length != 1 ) return;
         
      definition = paths[0].newCursor().getTextValue();
   }
   
	protected String assertRequest(WsdlTestRequest request) throws AssertionException
	{
		WsdlOperation operation = (WsdlOperation) request.getOperation();
		WsdlContext wsdlContext = null;
		if( definition == null || definition.trim().length() == 0)
		{
			wsdlContext = ((WsdlInterface)operation.getInterface()).getWsdlContext();
		}
		else
		{
			wsdlContext = new WsdlContext( definition );
		}
		
		WsdlValidator validator = new WsdlValidator( wsdlContext );
		
		try
		{
			AssertionError[] errors = validator.assertResponse(request
					.getResponseContent(), operation.getBindingOperationName());
			if (errors.length > 0)
				throw new AssertionException(errors);
		}
		catch( AssertionException e )
		{
			throw e;
		}
		catch (Exception e)
		{
			throw new AssertionException( new AssertionError( e.getMessage() ));
		}
		
		return "Schema compliance OK";
	}
	
   public void configure()
   {
   	String value = definition;
   	String orgDef = getRequest().getOperation().getInterface().getDefinition();
   	if( value == null || value.trim().length() == 0 )
   	{
			value = orgDef;
   	}
   	
      value = (String) JOptionPane.showInputDialog( SoapUI.getInstance().getFrame(), 
      		"Specify defintion url to validate by", 
      		"Configure SchemaCompliance Assertion", JOptionPane.QUESTION_MESSAGE, null, 
      		null, value );
      
      if( value == null ) return;
      
      if( value.trim().length() == 0 || value.equals( orgDef ))
      	definition = "";
      else
      	definition = value;
      
      setConfiguration( createConfiguration() );
   }

   protected XmlObject createConfiguration()
   {
      XmlObject config = XmlObject.Factory.newInstance();
      XmlCursor cursor = config.newCursor();
      cursor.toNextToken();
      cursor.beginElement( "definition" );
      cursor.insertChars( definition );
      cursor.dispose();
      return config;
   }

   public boolean isConfigurable()
   {
      return true;
   }
}
