/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.model.support;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.ArrayList;
import java.util.List;

import javax.swing.Action;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.impl.EmptyPanelBuilder;
import com.eviware.soapui.model.ModelItem;
import com.eviware.soapui.model.PanelBuilder;
import com.eviware.soapui.model.tree.AbstractTreeNode;
import com.eviware.soapui.model.tree.SoapUITreeModel;
import com.eviware.soapui.model.tree.SoapUITreeNode;

/**
 * Base-class for ModelItem implementations
 * 
 * @author Ole.Matzura
 */

public abstract class AbstractModelItem implements ModelItem
{
   private List<Action> actions;
   private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport( this );
   private SoapUITreeNode treeNode;

   protected void addAction( Action action )
   {
   	if( actions == null )
   		 actions = new ArrayList<Action>();
   	
      actions.add( action );
   }
   
   public Action[] getActions()
   {
   	if( actions == null )
   		return new Action[0];
   	
      return actions.toArray( new Action[actions.size()] );
   }
   
   public PanelBuilder getPanelBuilder()
   {
      return new EmptyPanelBuilder();
   }
   
   public String getDescription()
   {
      return getName();
   }
   
   public SoapUITreeNode getTreeNode()
   {
      if( treeNode == null )
      {
         treeNode = createTreeNode();
      }
      
      return treeNode;
   }
   
   public SoapUITreeModel getTreeModel()
   {
      return SoapUI.getInstance().getTreeModel();
   }
   
   protected abstract SoapUITreeNode createTreeNode();
   

   public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener)
   {
      propertyChangeSupport.addPropertyChangeListener( propertyName, listener );
   }

   public void addPropertyChangeListener(PropertyChangeListener listener)
   {
      propertyChangeSupport.addPropertyChangeListener( listener );
   }

   public void removePropertyChangeListener(PropertyChangeListener listener)
   {
      propertyChangeSupport.removePropertyChangeListener( listener );
   }
   
   protected void notifyPropertyChanged( String name, Object oldValue, Object newValue )
   {
      propertyChangeSupport.firePropertyChange( name, oldValue, newValue );
   }

   protected void notifyPropertyChanged( String name, int oldValue, int newValue )
   {
      propertyChangeSupport.firePropertyChange( name, oldValue, newValue );
   }

   protected void notifyPropertyChanged( String name, boolean oldValue, boolean newValue )
   {
      propertyChangeSupport.firePropertyChange( name, oldValue, newValue );
   }

   public void release()
   {
   	if( treeNode != null && treeNode instanceof AbstractTreeNode )
   		((AbstractTreeNode)treeNode).release();
   }
   
}
