/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.support;

import java.awt.BorderLayout;
import java.awt.HeadlessException;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JProgressBar;

import com.eviware.soapui.SoapUI;
import com.jgoodies.forms.builder.ButtonBarBuilder;

/**
 * Dialog for creating progress-dialogs
 * 
 * @author Ole.Matzura
 */

public class ProgressDialog extends JDialog
{
   private JProgressBar progressBar;

   private JLabel progressLabel;

	private final CancelHandler cancelHandler;

	private JButton cancelButton;

   public ProgressDialog(String title, String label, int length, String initialValue, CancelHandler cancelHandler ) throws HeadlessException
   {
      super(SoapUI.getInstance().getFrame(), title, true);
		this.cancelHandler = cancelHandler;

      setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
      setModal( true );

      progressBar = new JProgressBar(0, length);
      progressBar.setStringPainted(true);
      progressBar.setString(initialValue );
      progressBar.setIndeterminate(true);
      progressBar.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));

      getContentPane().setLayout(new BorderLayout());
      progressLabel = new JLabel(label);
      progressLabel.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));

      getContentPane().add(progressLabel, BorderLayout.NORTH);
      getContentPane().add(progressBar, BorderLayout.CENTER);
      
      if( cancelHandler != null )
      {
          ButtonBarBuilder builder = ButtonBarBuilder.createLeftToRightBuilder();	
          builder.addGlue();
          cancelButton = new JButton( new CancelAction());
			 builder.addFixed( cancelButton );
          builder.addGlue();
          builder.setBorder( BorderFactory.createEmptyBorder(0, 10, 10, 10) );
          getContentPane().add( builder.getPanel(), BorderLayout.SOUTH );
      }
      
      pack();
   }
   
   public void setProgress( int value, String string )
   {
      progressBar.setValue( value );
      progressBar.setString( string );
   }

   public void setVisible( boolean visible )
   {
      if( visible == true )
      {
         SoapUI.centerDialog( this );
      }
      
      super.setVisible( visible );
   }
   
   public interface CancelHandler
   {
   	public boolean onCancel();
   }
   
   private class CancelAction extends AbstractAction
   {
   	public CancelAction()
   	{
   		super( "Cancel" );
   	}
   	
		public void actionPerformed(ActionEvent e)
		{
			if( cancelHandler.onCancel() )
				ProgressDialog.this.setVisible( false );
		}
   }

	public void setCancelLabel(String label)
	{
		if( cancelButton != null )
			cancelButton.setText( label );
	}
}
