/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.support;

import java.awt.Component;

import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JSplitPane;

/**
 * Facade for common UI-related tasks
 * 
 * @author Ole.Matzura
 */

public class UISupport
{
	private static JFrame frame;

	public static void setMainFrame( JFrame frame )
	{
		UISupport.frame = frame;
	}
	
	public static JFrame getMainFrame()
	{
		return frame;
	}
	
	public static void showErrorMessage(String message)
	{
		JOptionPane.showMessageDialog( frame, message, "Error", JOptionPane.ERROR_MESSAGE );
	}

	public static boolean confirm(String question, String title)
	{
		return JOptionPane.showConfirmDialog( frame, question, title, JOptionPane.OK_CANCEL_OPTION ) == 
			JOptionPane.OK_OPTION;
	}

	public static String prompt(String question, String title, String value)
	{
		return (String) JOptionPane.showInputDialog( frame, question, title, JOptionPane.QUESTION_MESSAGE, 
				null, null, value );
	}

	public static String prompt(String question, String title)
	{
		return JOptionPane.showInputDialog(frame, question, title, JOptionPane.QUESTION_MESSAGE );
	}

	public static JSplitPane createHorizontalSplit()
	{
		JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT);
      splitPane.setUI( new SoapUISpliPaneUI() );
      splitPane.setDividerSize( 10 );
      splitPane.setOneTouchExpandable( true );
      return splitPane;
	}
	
	public static JSplitPane createHorizontalSplit( Component leftComponent, Component rightComponent )
	{
		JSplitPane splitPane = createHorizontalSplit();
		
		splitPane.setLeftComponent( leftComponent );
		splitPane.setRightComponent( rightComponent );
      return splitPane;
	}
	
	public static JSplitPane createVerticalSplit()
	{
		JSplitPane splitPane = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
      splitPane.setUI( new SoapUISpliPaneUI() );
      splitPane.setDividerSize( 10 );
      splitPane.setOneTouchExpandable( true );
      return splitPane;
	}
	
	public static JSplitPane createVerticalSplit( Component topComponent, Component bottomComponent )
	{
		JSplitPane splitPane = createVerticalSplit();
		
		splitPane.setLeftComponent( topComponent );
		splitPane.setRightComponent( bottomComponent );
      return splitPane;
	}
}
