package com.eviware.soapui.support.actions;

import java.awt.event.ActionEvent;
import java.io.FileWriter;
import java.io.IOException;

import javax.swing.AbstractAction;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import org.apache.log4j.Logger;

import com.eviware.soapui.SoapUI;
import com.eviware.soapui.support.ExtensionFileFilter;
import com.eviware.soapui.support.JXmlTextArea;

/**
 * Saves the XML of a JXmlTextArea
 * 
 * @author Ole.Matzura
 */

public class SaveXmlTextAreaAction extends AbstractAction
{
	private JFileChooser chooser;
	private final JXmlTextArea textArea;
	private String dialogTitle;
	private static final Logger log = Logger.getLogger( SaveXmlTextAreaAction.class );
	
	public SaveXmlTextAreaAction( JXmlTextArea textArea, String dialogTitle )
	{
		super( "Save as.." );
		this.textArea = textArea;
		this.dialogTitle = dialogTitle;
	}
	
	public void actionPerformed(ActionEvent e)
	{
		if( chooser == null )
		{
			chooser = new JFileChooser();
			chooser.setDialogTitle( dialogTitle );
			chooser.setAcceptAllFileFilterUsed( true );
         chooser.setFileFilter( new ExtensionFileFilter( ".xml", "XML Files (*.xml)"));
		}
		
		if( JFileChooser.APPROVE_OPTION != chooser.showSaveDialog( SoapUI.getInstance().getFrame() ))
				return;
		
		try
		{
			FileWriter writer = new FileWriter( chooser.getSelectedFile());
			writer.write( textArea.getText() );
			
			log.info( "XML written to [" + chooser.getSelectedFile().getAbsolutePath() + "]" );
			writer.close();
		}
		catch (IOException e1)
		{
			JOptionPane.showMessageDialog( SoapUI.getInstance().getFrame(), 
					"Error saving xml to file: " + e1.getMessage(), "Error saving XML", JOptionPane.ERROR_MESSAGE );
		}
	}
}