/*
 *  soapui, copyright (C) 2005 Ole Matzura / eviware.com 
 *
 *  SoapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of the GNU Lesser General Public License as published by the Free Software Foundation; 
 *  either version 2.1 of the License, or (at your option) any later version.
 *
 *  SoapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.model.impl.wsdl;

import junit.framework.TestCase;

import com.eviware.soapui.impl.wsdl.WsdlProject;
import com.eviware.soapui.impl.wsdl.WsdlTestCase;
import com.eviware.soapui.impl.wsdl.teststeps.WsdlAssertion;
import com.eviware.soapui.impl.wsdl.teststeps.WsdlTestRequestStep;
import com.eviware.soapui.impl.wsdl.teststeps.WsdlAssertion.AssertionStatus;
import com.eviware.soapui.model.iface.Submit;
import com.eviware.soapui.model.testsuite.TestRunListener;
import com.eviware.soapui.model.testsuite.TestRunner;
import com.eviware.soapui.model.testsuite.TestStep;
import com.eviware.soapui.model.testsuite.TestSuite;

public class WsdlProjectTestCase extends TestCase implements TestRunListener
{
	public void testLoad() throws Exception
	{
		WsdlProject project = new WsdlProject( "Test-soapui-project.xml" );
		TestSuite testSuite = project.getTestSuiteAt( 0 );
		WsdlTestCase testCase = (WsdlTestCase) testSuite.getTestCaseAt( 0 );

		testCase.addTestRunListener( this );
		testCase.run().waitUntilFinished();
	}

	public boolean beforeRun(TestRunner testRunner)
	{
		return true;
	}

	public boolean beforeStep(TestRunner testRunner)
	{
		return true;
	}

	public boolean afterStep(TestRunner testRunner)
	{
		TestStep currentStep = testRunner.getCurrentStep();
		
		if( currentStep instanceof WsdlTestRequestStep )
		{
			WsdlTestRequestStep requestStep = (WsdlTestRequestStep) currentStep;
			for( int c = 0; c < requestStep.getAssertionCount(); c++ )
			{
				WsdlAssertion assertion = requestStep.getAssertionAt( c );
				System.out.println( "Assertion [" + assertion.getName() + "] has status " + assertion.getStatus());
				if( assertion.getStatus() == AssertionStatus.FAILED )
				{
					System.out.println( "-> " + assertion.getErrors());
				}
			}
		}	
		
		return true;
	}

	public void afterRun(TestRunner testRunner)
	{
	}

	public boolean onSubmit(Submit submit)
	{
		return true;
	}

	public void afterSubmit(Submit submit)
	{
	}
	
}
